<?php
/**
 * VW Kindergarten Theme Customizer
 *
 * @package VW Kindergarten
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function vw_kindergarten_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_kindergarten_custom_controls' );

function vw_kindergarten_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; 
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'vw_kindergarten_Customize_partial_blogname',
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'vw_kindergarten_Customize_partial_blogdescription',
	));

	// add home page setting pannel
	$wp_customize->add_panel( 'vw_kindergarten_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'VW Settings', 'vw-kindergarten' ),
		'priority' => 10,
	));

	// Layout
	$wp_customize->add_section( 'vw_kindergarten_left_right', array(
    	'title' => esc_html__( 'General Settings', 'vw-kindergarten' ),
		'panel' => 'vw_kindergarten_panel_id'
	) );

	$wp_customize->add_setting('vw_kindergarten_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'vw_kindergarten_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Kindergarten_Image_Radio_Control($wp_customize, 'vw_kindergarten_width_option', array(
        'type' => 'select',
        'label' => esc_html__('Width Layouts','vw-kindergarten'),
        'description' => esc_html__('Here you can change the width layout of Website.','vw-kindergarten'),
        'section' => 'vw_kindergarten_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('vw_kindergarten_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'vw_kindergarten_sanitize_choices'
	));
	$wp_customize->add_control('vw_kindergarten_theme_options',array(
        'type' => 'select',
        'label' => esc_html__('Post Sidebar Layout','vw-kindergarten'),
        'description' => esc_html__('Here you can change the sidebar layout for posts. ','vw-kindergarten'),
        'section' => 'vw_kindergarten_left_right',
        'choices' => array(
            'Left Sidebar' => esc_html__('Left Sidebar','vw-kindergarten'),
            'Right Sidebar' => esc_html__('Right Sidebar','vw-kindergarten'),
            'One Column' => esc_html__('One Column','vw-kindergarten'),
            'Grid Layout' => esc_html__('Grid Layout','vw-kindergarten')
        ),
	) );

	$wp_customize->add_setting('vw_kindergarten_page_layout',array(
        'default' => 'One_Column',
        'sanitize_callback' => 'vw_kindergarten_sanitize_choices'
	));
	$wp_customize->add_control('vw_kindergarten_page_layout',array(
        'type' => 'select',
        'label' => esc_html__('Page Sidebar Layout','vw-kindergarten'),
        'description' => esc_html__('Here you can change the sidebar layout for pages. ','vw-kindergarten'),
        'section' => 'vw_kindergarten_left_right',
        'choices' => array(
            'Left_Sidebar' => esc_html__('Left Sidebar','vw-kindergarten'),
            'Right_Sidebar' => esc_html__('Right Sidebar','vw-kindergarten'),
            'One_Column' => esc_html__('One Column','vw-kindergarten')
        ),
	) );

	// Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_kindergarten_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar', 
		'render_callback' => 'vw_kindergarten_customize_partial_vw_kindergarten_woocommerce_shop_page_sidebar', ) );

    // Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'vw_kindergarten_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_kindergarten_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Kindergarten_Toggle_Switch_Custom_Control( $wp_customize, 'vw_kindergarten_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','vw-kindergarten' ),
		'section' => 'vw_kindergarten_left_right'
    )));

    // Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_kindergarten_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar', 
		'render_callback' => 'vw_kindergarten_customize_partial_vw_kindergarten_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'vw_kindergarten_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_kindergarten_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Kindergarten_Toggle_Switch_Custom_Control( $wp_customize, 'vw_kindergarten_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','vw-kindergarten' ),
		'section' => 'vw_kindergarten_left_right'
    )));

    // Pre-Loader
	$wp_customize->add_setting( 'vw_kindergarten_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_kindergarten_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Kindergarten_Toggle_Switch_Custom_Control( $wp_customize, 'vw_kindergarten_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','vw-kindergarten' ),
        'section' => 'vw_kindergarten_left_right'
    )));

	$wp_customize->add_setting('vw_kindergarten_preloader_bg_color', array(
		'default'           => '#404376',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_kindergarten_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'vw-kindergarten'),
		'section'  => 'vw_kindergarten_left_right',
	)));

	$wp_customize->add_setting('vw_kindergarten_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_kindergarten_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'vw-kindergarten'),
		'section'  => 'vw_kindergarten_left_right',
	)));

	// Top Bar
	$wp_customize->add_section( 'vw_kindergarten_top_bar' , array(
    	'title' => esc_html__( 'Top Bar', 'vw-kindergarten' ),
		'panel' => 'vw_kindergarten_panel_id'
	) );

	$wp_customize->add_setting('vw_kindergarten_phone_number',array(
		'default'=> '',
		'sanitize_callback'	=> 'vw_kindergarten_sanitize_phone_number'
	));
	$wp_customize->add_control('vw_kindergarten_phone_number',array(
		'label'	=> esc_html__('Add Phone No.','vw-kindergarten'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '+1234567890', 'vw-kindergarten' ),
        ),
		'section'=> 'vw_kindergarten_top_bar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_kindergarten_email_address',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_email'
	));
	$wp_customize->add_control('vw_kindergarten_email_address',array(
		'label'	=> esc_html__('Add Email Address','vw-kindergarten'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'example@gmail.com', 'vw-kindergarten' ),
        ),
		'section'=> 'vw_kindergarten_top_bar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_kindergarten_navigation_menu_font_weight',array(
        'default' => 'Default',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_kindergarten_sanitize_choices'
	));
	$wp_customize->add_control('vw_kindergarten_navigation_menu_font_weight',array(
        'type' => 'select',
        'label' => __('Menus Font Weight','vw-kindergarten'),
        'section' => 'vw_kindergarten_top_bar',
        'choices' => array(
        	'Default' => __('Default','vw-kindergarten'),
            'Normal' => __('Normal','vw-kindergarten')
        ),
	) );

	//Slider
	$wp_customize->add_section( 'vw_kindergarten_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'vw-kindergarten' ),
		'panel' => 'vw_kindergarten_panel_id'
	) );

	$wp_customize->add_setting( 'vw_kindergarten_slider_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_kindergarten_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Kindergarten_Toggle_Switch_Custom_Control( $wp_customize, 'vw_kindergarten_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','vw-kindergarten' ),
      'section' => 'vw_kindergarten_slidersettings'
    )));

     //Selective Refresh
    $wp_customize->selective_refresh->add_partial('vw_kindergarten_slider_hide_show',array(
		'selector'        => '.slider-btn a',
		'render_callback' => 'vw_kindergarten_customize_partial_vw_kindergarten_slider_hide_show',
	));

	for ( $count = 1; $count <= 4; $count++ ) {
		$wp_customize->add_setting( 'vw_kindergarten_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_kindergarten_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_kindergarten_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'vw-kindergarten' ),
			'description' => __('Slider image size (1500 x 600)','vw-kindergarten'),
			'section'  => 'vw_kindergarten_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	$wp_customize->add_setting('vw_kindergarten_slider_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_kindergarten_slider_button_text',array(
		'label'	=> __('Add Slider Button Text','vw-kindergarten'),
		'input_attrs' => array(
            'placeholder' => __( 'Discover More', 'vw-kindergarten' ),
        ),
		'section'=> 'vw_kindergarten_slidersettings',
		'type'=> 'text'
	));

	//content layout
	$wp_customize->add_setting('vw_kindergarten_slider_content_option',array(
        'default' => 'Left',
        'sanitize_callback' => 'vw_kindergarten_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Kindergarten_Image_Radio_Control($wp_customize, 'vw_kindergarten_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','vw-kindergarten'),
        'section' => 'vw_kindergarten_slidersettings',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/slider-content1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/slider-content2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'vw_kindergarten_slider_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_kindergarten_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_kindergarten_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-kindergarten' ),
		'section'     => 'vw_kindergarten_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_kindergarten_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('vw_kindergarten_slider_opacity_color',array(
		'default'              => 0.3,
		'sanitize_callback' => 'vw_kindergarten_sanitize_choices'
	));

	$wp_customize->add_control( 'vw_kindergarten_slider_opacity_color', array(
		'label'       => esc_html__( 'Slider Image Opacity','vw-kindergarten' ),
		'section'     => 'vw_kindergarten_slidersettings',
		'type'        => 'select',
		'settings'    => 'vw_kindergarten_slider_opacity_color',
		'choices' => array(
			'0' =>  esc_attr('0','vw-kindergarten'),
			'0.1' =>  esc_attr('0.1','vw-kindergarten'),
			'0.2' =>  esc_attr('0.2','vw-kindergarten'),
			'0.3' =>  esc_attr('0.3','vw-kindergarten'),
			'0.4' =>  esc_attr('0.4','vw-kindergarten'),
			'0.5' =>  esc_attr('0.5','vw-kindergarten'),
			'0.6' =>  esc_attr('0.6','vw-kindergarten'),
			'0.7' =>  esc_attr('0.7','vw-kindergarten'),
			'0.8' =>  esc_attr('0.8','vw-kindergarten'),
			'0.9' =>  esc_attr('0.9','vw-kindergarten')
		),
	));

	//Slider height
	$wp_customize->add_setting('vw_kindergarten_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_kindergarten_slider_height',array(
		'label'	=> __('Slider Height','vw-kindergarten'),
		'description'	=> __('Specify the slider height (px).','vw-kindergarten'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'vw-kindergarten' ),
        ),
		'section'=> 'vw_kindergarten_slidersettings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_kindergarten_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'vw_kindergarten_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','vw-kindergarten'),
		'section' => 'vw_kindergarten_slidersettings',
		'type'  => 'text',
	) );

	// About Section
	$wp_customize->add_section('vw_kindergarten_about_section',array(
		'title'	=> __('About Section','vw-kindergarten'),
		'description' => __('Add section title and Select the Page to display for about.','vw-kindergarten'),
		'panel' => 'vw_kindergarten_panel_id',
	));

	$wp_customize->add_setting( 'vw_kindergarten_section_title', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'vw_kindergarten_section_title', array(
		'label'    => __( 'Add Section Title', 'vw-kindergarten' ),
		'input_attrs' => array(
            'placeholder' => __( 'About Us', 'vw-kindergarten' ),
        ),
		'section'  => 'vw_kindergarten_about_section',
		'type'     => 'text'
	) );

	$wp_customize->add_setting( 'vw_kindergarten_about_page', array(
		'default'           => '',
		'sanitize_callback' => 'vw_kindergarten_sanitize_dropdown_pages'
	) );
	$wp_customize->add_control( 'vw_kindergarten_about_page', array(
		'label'    => __( 'Select Page of About', 'vw-kindergarten' ),
		'description'	=> __('About image size (400 x 400)','vw-kindergarten'),
		'section'  => 'vw_kindergarten_about_section',
		'type'     => 'dropdown-pages'
	) );

	$wp_customize->add_setting( 'vw_kindergarten_image_text', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'vw_kindergarten_image_text', array(
		'label'    => __( 'Add Image Text', 'vw-kindergarten' ),
		'input_attrs' => array(
            'placeholder' => __( 'Trusted By 5799+', 'vw-kindergarten' ),
        ),
		'section'  => 'vw_kindergarten_about_section',
		'type'     => 'text'
	) );

	//Blog Post
	$wp_customize->add_panel( 'vw_kindergarten_blog_post_parent_panel', array(
		'title' => esc_html__( 'Blog Post Settings', 'vw-kindergarten' ),
		'panel' => 'vw_kindergarten_panel_id',
		'priority' => 20,
	));

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'vw_kindergarten_post_settings', array(
		'title' => esc_html__( 'Post Settings', 'vw-kindergarten' ),
		'panel' => 'vw_kindergarten_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_kindergarten_toggle_postdate', array( 
		'selector' => '.post-main-box h2 a', 
		'render_callback' => 'vw_kindergarten_Customize_partial_vw_kindergarten_toggle_postdate', 
	));

	$wp_customize->add_setting( 'vw_kindergarten_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_kindergarten_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Kindergarten_Toggle_Switch_Custom_Control( $wp_customize, 'vw_kindergarten_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-kindergarten' ),
        'section' => 'vw_kindergarten_post_settings'
    )));

    $wp_customize->add_setting( 'vw_kindergarten_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_kindergarten_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Kindergarten_Toggle_Switch_Custom_Control( $wp_customize, 'vw_kindergarten_toggle_author',array(
		'label' => esc_html__( 'Author','vw-kindergarten' ),
		'section' => 'vw_kindergarten_post_settings'
    )));

    $wp_customize->add_setting( 'vw_kindergarten_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_kindergarten_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Kindergarten_Toggle_Switch_Custom_Control( $wp_customize, 'vw_kindergarten_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-kindergarten' ),
		'section' => 'vw_kindergarten_post_settings'
    )));

    $wp_customize->add_setting( 'vw_kindergarten_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_kindergarten_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Kindergarten_Toggle_Switch_Custom_Control( $wp_customize, 'vw_kindergarten_toggle_time',array(
		'label' => esc_html__( 'Time','vw-kindergarten' ),
		'section' => 'vw_kindergarten_post_settings'
    )));

    $wp_customize->add_setting( 'vw_kindergarten_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_kindergarten_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Kindergarten_Toggle_Switch_Custom_Control( $wp_customize, 'vw_kindergarten_featured_image_hide_show', array(
		'label' => esc_html__( 'Featured Image','vw-kindergarten' ),
		'section' => 'vw_kindergarten_post_settings'
    )));

    $wp_customize->add_setting( 'vw_kindergarten_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_kindergarten_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Kindergarten_Toggle_Switch_Custom_Control( $wp_customize, 'vw_kindergarten_toggle_tags', array(
		'label' => esc_html__( 'Tags','vw-kindergarten' ),
		'section' => 'vw_kindergarten_post_settings'
    )));

    $wp_customize->add_setting( 'vw_kindergarten_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_kindergarten_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_kindergarten_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-kindergarten' ),
		'section'     => 'vw_kindergarten_post_settings',
		'type'        => 'range',
		'settings'    => 'vw_kindergarten_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_kindergarten_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_kindergarten_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','vw-kindergarten'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','vw-kindergarten'),
		'section'=> 'vw_kindergarten_post_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('vw_kindergarten_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_kindergarten_sanitize_choices'
	));
	$wp_customize->add_control('vw_kindergarten_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Post Content','vw-kindergarten'),
        'section' => 'vw_kindergarten_post_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','vw-kindergarten'),
            'Excerpt' => esc_html__('Excerpt','vw-kindergarten'),
            'No Content' => esc_html__('No Content','vw-kindergarten')
        ),
	) );

    // Button Settings
	$wp_customize->add_section( 'vw_kindergarten_button_settings', array(
		'title' => esc_html__( 'Button Settings', 'vw-kindergarten' ),
		'panel' => 'vw_kindergarten_blog_post_parent_panel',
	));

	$wp_customize->add_setting( 'vw_kindergarten_button_border_radius', array(
		'default'              => 5,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_kindergarten_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_kindergarten_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','vw-kindergarten' ),
		'section'     => 'vw_kindergarten_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_kindergarten_button_text', array( 
		'selector' => '.post-main-box .more-btn a', 
		'render_callback' => 'vw_kindergarten_Customize_partial_vw_kindergarten_button_text', 
	));

    $wp_customize->add_setting('vw_kindergarten_button_text',array(
		'default'=> esc_html__('Read More','vw-kindergarten'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_kindergarten_button_text',array(
		'label'	=> esc_html__('Add Button Text','vw-kindergarten'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'vw-kindergarten' ),
        ),
		'section'=> 'vw_kindergarten_button_settings',
		'type'=> 'text'
	));

	// Related Post Settings
	$wp_customize->add_section( 'vw_kindergarten_related_posts_settings', array(
		'title' => esc_html__( 'Related Posts Settings', 'vw-kindergarten' ),
		'panel' => 'vw_kindergarten_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_kindergarten_related_post_title', array( 
		'selector' => '.related-post h3', 
		'render_callback' => 'vw_kindergarten_Customize_partial_vw_kindergarten_related_post_title', 
	));

    $wp_customize->add_setting( 'vw_kindergarten_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_kindergarten_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Kindergarten_Toggle_Switch_Custom_Control( $wp_customize, 'vw_kindergarten_related_post',array(
		'label' => esc_html__( 'Related Post','vw-kindergarten' ),
		'section' => 'vw_kindergarten_related_posts_settings'
    )));

    $wp_customize->add_setting('vw_kindergarten_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_kindergarten_related_post_title',array(
		'label'	=> esc_html__('Add Related Post Title','vw-kindergarten'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Related Post', 'vw-kindergarten' ),
        ),
		'section'=> 'vw_kindergarten_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('vw_kindergarten_related_posts_count',array(
		'default'=> 3,
		'sanitize_callback'	=> 'vw_kindergarten_sanitize_number_absint'
	));
	$wp_customize->add_control('vw_kindergarten_related_posts_count',array(
		'label'	=> esc_html__('Add Related Post Count','vw-kindergarten'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '3', 'vw-kindergarten' ),
        ),
		'section'=> 'vw_kindergarten_related_posts_settings',
		'type'=> 'number'
	));

	// Single Posts Settings
	$wp_customize->add_section( 'vw_kindergarten_single_blog_settings', array(
		'title' => __( 'Single Post Settings', 'vw-kindergarten' ),
		'panel' => 'vw_kindergarten_blog_post_parent_panel',
	));

	$wp_customize->add_setting('vw_kindergarten_single_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_kindergarten_single_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','vw-kindergarten'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','vw-kindergarten'),
		'section'=> 'vw_kindergarten_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_kindergarten_single_blog_comment_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_kindergarten_single_blog_comment_title',array(
		'label'	=> __('Add Comment Title','vw-kindergarten'),
		'input_attrs' => array(
            'placeholder' => __( 'Leave a Reply', 'vw-kindergarten' ),
        ),
		'section'=> 'vw_kindergarten_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_kindergarten_single_blog_comment_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_kindergarten_single_blog_comment_button_text',array(
		'label'	=> __('Add Comment Button Text','vw-kindergarten'),
		'input_attrs' => array(
            'placeholder' => __( 'Post Comment', 'vw-kindergarten' ),
        ),
		'section'=> 'vw_kindergarten_single_blog_settings',
		'type'=> 'text'
	));

	//Responsive Media Settings
	$wp_customize->add_section('vw_kindergarten_responsive_media',array(
		'title'	=> esc_html__('Responsive Media','vw-kindergarten'),
		'panel' => 'vw_kindergarten_panel_id',
	));

    $wp_customize->add_setting( 'vw_kindergarten_resp_slider_hide_show',array(
      	'default' => 0,
     	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_kindergarten_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Kindergarten_Toggle_Switch_Custom_Control( $wp_customize, 'vw_kindergarten_resp_slider_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Slider','vw-kindergarten' ),
      	'section' => 'vw_kindergarten_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_kindergarten_sidebar_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_kindergarten_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Kindergarten_Toggle_Switch_Custom_Control( $wp_customize, 'vw_kindergarten_sidebar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Sidebar','vw-kindergarten' ),
      	'section' => 'vw_kindergarten_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_kindergarten_resp_scroll_top_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_kindergarten_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Kindergarten_Toggle_Switch_Custom_Control( $wp_customize, 'vw_kindergarten_resp_scroll_top_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-kindergarten' ),
      	'section' => 'vw_kindergarten_responsive_media'
    )));

    $wp_customize->add_setting('vw_kindergarten_res_open_menu_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Kindergarten_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_kindergarten_res_open_menu_icon',array(
		'label'	=> __('Add Open Menu Icon','vw-kindergarten'),
		'transport' => 'refresh',
		'section'	=> 'vw_kindergarten_responsive_media',
		'setting'	=> 'vw_kindergarten_res_open_menu_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_kindergarten_res_menu_close_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Kindergarten_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_kindergarten_res_menu_close_icon',array(
		'label'	=> __('Add Close Menu Icon','vw-kindergarten'),
		'transport' => 'refresh',
		'section'	=> 'vw_kindergarten_responsive_media',
		'setting'	=> 'vw_kindergarten_res_menu_close_icon',
		'type'		=> 'icon'
	)));

	//Footer Text
	$wp_customize->add_section('vw_kindergarten_footer',array(
		'title'	=> esc_html__('Footer Settings','vw-kindergarten'),
		'panel' => 'vw_kindergarten_panel_id',
	));	

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_kindergarten_footer_text', array( 
		'selector' => '.copyright p', 
		'render_callback' => 'vw_kindergarten_Customize_partial_vw_kindergarten_footer_text', 
	));
	
	$wp_customize->add_setting('vw_kindergarten_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_kindergarten_footer_text',array(
		'label'	=> esc_html__('Copyright Text','vw-kindergarten'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Copyright 2021, .....', 'vw-kindergarten' ),
        ),
		'section'=> 'vw_kindergarten_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_kindergarten_copyright_alingment',array(
        'default' => 'center',
        'sanitize_callback' => 'vw_kindergarten_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Kindergarten_Image_Radio_Control($wp_customize, 'vw_kindergarten_copyright_alingment', array(
        'type' => 'select',
        'label' => esc_html__('Copyright Alignment','vw-kindergarten'),
        'section' => 'vw_kindergarten_footer',
        'settings' => 'vw_kindergarten_copyright_alingment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
    ))));

    $wp_customize->add_setting( 'vw_kindergarten_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_kindergarten_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Kindergarten_Toggle_Switch_Custom_Control( $wp_customize, 'vw_kindergarten_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll to Top','vw-kindergarten' ),
      	'section' => 'vw_kindergarten_footer'
    )));

     //Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_kindergarten_scroll_to_top_icon', array( 
		'selector' => '.scrollup i', 
		'render_callback' => 'vw_kindergarten_Customize_partial_vw_kindergarten_scroll_to_top_icon', 
	));

    $wp_customize->add_setting('vw_kindergarten_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'vw_kindergarten_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Kindergarten_Image_Radio_Control($wp_customize, 'vw_kindergarten_scroll_top_alignment', array(
        'type' => 'select',
        'label' => esc_html__('Scroll To Top','vw-kindergarten'),
        'section' => 'vw_kindergarten_footer',
        'settings' => 'vw_kindergarten_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/layout3.png'
    ))));

    //Woocommerce settings
	$wp_customize->add_section('vw_kindergarten_woocommerce_section', array(
		'title'    => __('WooCommerce Layout', 'vw-kindergarten'),
		'priority' => null,
		'panel'    => 'woocommerce',
	));

	$wp_customize->add_setting('vw_kindergarten_products_btn_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_kindergarten_products_btn_padding_top_bottom',array(
		'label'	=> __('Products Button Padding Top Bottom','vw-kindergarten'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-kindergarten'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-kindergarten' ),
        ),
		'section'=> 'vw_kindergarten_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_kindergarten_products_btn_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_kindergarten_products_btn_padding_left_right',array(
		'label'	=> __('Products Button Padding Left Right','vw-kindergarten'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-kindergarten'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-kindergarten' ),
        ),
		'section'=> 'vw_kindergarten_woocommerce_section',
		'type'=> 'text'
	));

    //Products Sale Badge
	$wp_customize->add_setting('vw_kindergarten_woocommerce_sale_position',array(
        'default' => 'left',
        'sanitize_callback' => 'vw_kindergarten_sanitize_choices'
	));
	$wp_customize->add_control('vw_kindergarten_woocommerce_sale_position',array(
        'type' => 'select',
        'label' => __('Sale Badge Position','vw-kindergarten'),
        'section' => 'vw_kindergarten_woocommerce_section',
        'choices' => array(
            'left' => __('Left','vw-kindergarten'),
            'right' => __('Right','vw-kindergarten'),
        ),
	) );

	$wp_customize->add_setting('vw_kindergarten_woocommerce_sale_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_kindergarten_woocommerce_sale_font_size',array(
		'label'	=> __('Sale Font Size','vw-kindergarten'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-kindergarten'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-kindergarten' ),
        ),
		'section'=> 'vw_kindergarten_woocommerce_section',
		'type'=> 'text'
	));
}

add_action( 'customize_register', 'vw_kindergarten_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Kindergarten_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Kindergarten_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new VW_Kindergarten_Customize_Section_Pro( $manager,'vw_kindergarten_go_pro', array(
			'priority'   => 1,
			'title'    => esc_html__( 'KINDERGARTEN PRO', 'vw-kindergarten' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'vw-kindergarten' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/kindergarten-wordpress-theme/'),
		) )	);

		// Register sections.
		$manager->add_section(new VW_Kindergarten_Customize_Section_Pro($manager,'vw_kindergarten_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'vw-kindergarten' ),
			'pro_text' => esc_html__( 'DOCS', 'vw-kindergarten' ),
			'pro_url'  => admin_url('themes.php?page=vw_kindergarten_guide'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-kindergarten-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-kindergarten-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Kindergarten_Customize::get_instance();